# jeans

A package for ...

Author: Matthew G. Walker (2024) 

# Instructions 

* Install jeans. You can either pip install the released version or install from github

```
pip install jeans
```
# Available Models for 2D position

xxx

In order to ...:

```dmhalo=jeans.dmhalo('nfw',triangle=200,m_triangle=1.e+10,c_triangle=10)```

# Examples 

For examples of ...

# Acknowledgement

